@@ -26,15 +26,12 @@
 #include <libnotify/notify.h>
 #include <gdk/gdk.h>
 #include <stdlib.h>
+#include <lcms2.h>
 
 #ifdef HAVE_LIBCANBERRA
 #include <canberra-gtk.h>
 #endif
 
-#ifdef HAVE_LCMS
-  #include <lcms2.h>
-#endif
-
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #include <libgnome-desktop/gnome-rr.h>
 
@@ -546,7 +543,7 @@ gcm_apply_create_icc_profile_for_edid (GsdColorManager *manager,
         cmsCIExyYTRIPLE chroma;
         cmsCIExyY white_point;
         cmsHPROFILE lcms_profile = NULL;
-        cmsToneCurve *transfer_curve[3];
+        cmsToneCurve *transfer_curve[3] = { NULL, NULL, NULL };
         const gchar *data;
         gboolean ret = FALSE;
         gchar *title = NULL;
@@ -1360,6 +1357,15 @@ gcm_session_client_connect_cb (GObject *source_object,
                 return;
         }
 
+#if CD_CHECK_VERSION(0,1,12)
+        /* is there an available colord instance? */
+        ret = cd_client_get_has_server (manager->priv->client);
+        if (!ret) {
+                g_warning ("There is no colord server available");
+                goto out;
+        }
+#endif
+
         /* add profiles */
         gcm_profile_store_search (priv->profile_store);
 
@@ -1726,7 +1732,6 @@ gcm_session_device_added_notify_cb (CdClient *client,
                            manager);
 }
 
-#ifdef HAVE_LCMS
 static gchar *
 gcm_session_get_precooked_md5 (cmsHPROFILE lcms_profile)
 {
@@ -1753,7 +1758,6 @@ gcm_session_get_precooked_md5 (cmsHPROFILE lcms_profile)
 out:
         return md5;
 }
-#endif
 
 static gchar *
 gcm_session_get_md5_for_filename (const gchar *filename,
@@ -1763,8 +1767,6 @@ gcm_session_get_md5_for_filename (const gchar *filename,
         gchar *checksum = NULL;
         gchar *data = NULL;
         gsize length;
-
-#ifdef HAVE_LCMS
         cmsHPROFILE lcms_profile = NULL;
 
         /* get the internal profile id, if it exists */
@@ -1779,7 +1781,6 @@ gcm_session_get_md5_for_filename (const gchar *filename,
         checksum = gcm_session_get_precooked_md5 (lcms_profile);
         if (checksum != NULL)
                 goto out;
-#endif
 
         /* generate checksum */
         ret = g_file_get_contents (filename, &data, &length, error);
@@ -1790,10 +1791,8 @@ gcm_session_get_md5_for_filename (const gchar *filename,
                                                 length);
 out:
         g_free (data);
-#ifdef HAVE_LCMS
         if (lcms_profile != NULL)
                 cmsCloseProfile (lcms_profile);
-#endif
         return checksum;
 }
 
@@ -2055,7 +2054,7 @@ gsd_color_manager_finalize (GObject *object)
         g_object_unref (manager->priv->profile_store);
         g_object_unref (manager->priv->dmi);
         g_hash_table_destroy (manager->priv->edid_cache);
-        if (manager->priv->x11_screen != NULL);
+        if (manager->priv->x11_screen != NULL)
                 g_object_unref (manager->priv->x11_screen);
 
         G_OBJECT_CLASS (gsd_color_manager_parent_class)->finalize (object);
